/******************************************************************************

    Echoes is a RF spectrograph for RTL-SDR devices designed for meteor scatter
    Copyright (C) 2018  Giuseppe Massimo Bertani gmbertani(a)users.sourceforge.net


    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, version 3 of the License.
    

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, http://www.gnu.org/copyleft/gpl.html






*******************************************************************************
$Rev:: 23                       $: Revision of last commit
$Author:: gmbertani             $: Author of last commit
$Date:: 2018-01-17 17:28:16 +01#$: Date of last commit
$Id: iqbuf.cpp 23 2018-01-17 16:28:16Z gmbertani $
*******************************************************************************/

#include "settings.h"
#include "iqbuf.h"

int IQbuf::idGen = 0;

IQbuf::IQbuf(int maxDoublets)
{
    physWordSize = maxDoublets;
    byteSize = maxDoublets * 2;
    wordSize = physWordSize;

    buf8 = new uchar [ byteSize ];
    MY_ASSERT( nullptr !=   buf8 );

    idGen++;
    uid = idGen;
    MYDEBUG << "creating buffer [" << uid << "], " << wordSize << " IQ doublets, " << byteSize << " bytes total.";
    clear();
}

IQbuf::~IQbuf()
{
    if(buf8 != nullptr)
    {
        MYDEBUG << "deleting buffer, " << physWordSize << " doublets wide";
        delete[] buf8;
        buf8 = nullptr;
    }
}


bool IQbuf::setBufSize( int doublets )
{
    if(doublets <= physWordSize)
    {
        wordSize = doublets;
        byteSize = 2*wordSize;
        clear();
        return true;
    }

    //required a size bigger than physical
    return false;
}

void IQbuf::clear()
{
    QMutexLocker ml(&mx);

    MY_ASSERT( nullptr !=  buf8);

    int i;
    for(i=0; i < (byteSize-1); i += 2)
    {
        buf8[i]     = 0;        //real
        buf8[i+1]   = 128;      //imaginary
    }

    MYDEBUG << "zeroing buffer (" << uid << "), " << wordSize << " doublets wide";

}
