/******************************************************************************

    Echoes is a RF spectrograph for RTL-SDR devices designed for meteor scatter
    Copyright (C) 2018  Giuseppe Massimo Bertani gmbertani(a)users.sourceforge.net


    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, version 3 of the License.
    

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, http://www.gnu.org/copyleft/gpl.html






*******************************************************************************
$Rev:: 65                       $: Revision of last commit
$Author:: gmbertani             $: Author of last commit
$Date:: 2018-02-06 00:18:10 +01#$: Date of last commit
$Id: iqbuf.h 65 2018-02-05 23:18:10Z gmbertani $
*******************************************************************************/


#ifndef IQBUF_H
#define IQBUF_H

#include <QtCore>



class IQbuf
{
    uchar*      buf8;
    int         physWordSize;       //< maximum physical I+Q doublets allocated size
    int         wordSize;           //< logical number of I+Q doublets
    int         byteSize;           //< logical number of bytes in buffer
    QString     tsString;          //< capture timestamp

    QMutex mx;

    int         uid;         //< unique identifier in pool
    static int  idGen;       //< unique identifiers generator

public:
    ///
    /// \brief IQbuf
    /// \param size     physical number of iq doublets
    ///
    ///  the memory allocated for each iqbuf remains maxDoublets
    /// while the logical size (containing valid data) can be
    /// changed at runtime, reflecting the sample rate and
    /// bandwidth chosen
    ///
    explicit IQbuf(int maxDoublets);

    ///
    ~IQbuf();

    ///
    /// \brief data
    /// \return
    ///
    uchar* data() const
    {
        return buf8;
    }

    ///
    /// \brief setBufSize
    /// \param doublets
    /// \return true if ok
    ///
    /// changes the buffer's logical size
    ///
    bool setBufSize( int doublets );

    ///
    /// \brief setTimeStamp
    /// \param ts
    ///
    void setTimeStamp(QString& ts)
    {
        QMutexLocker ml(&mx);
        tsString = ts;
    }

    ///
    /// \brief myId
    /// \return
    ///
    int myUID() const
    {
        return uid;
    }

    ///
    /// \brief IQptr
    /// \param at
    /// \return
    ///
    uchar* IQptr(int at) const
    {
        Q_ASSERT(at < wordSize);
        return &buf8[at * 2];
    }

    ///
    /// \brief clear
    ///
    void clear();

    ///
    /// \brief bSize
    /// \return the logical size in bytes
    ///
    int bSize() const
    {
        return byteSize;
    }

    ///
    /// \brief doublets
    /// \return the logical size in doublets
    ///
    int doublets() const
    {
        return wordSize;
    }

    ///
    /// \brief maxSize
    /// \return
    ///
    int maxSize() const
    {
        return physWordSize;
    }

    ///
    /// \brief getTimeStamp
    /// \return
    ///
    QString timeStamp() const
    {
        return tsString;
    }

};




#endif // IQBUF_H
