/******************************************************************************

    Echoes is a RF spectrograph for RTL-SDR devices designed for meteor scatter
    Copyright (C) 2018  Giuseppe Massimo Bertani gmbertani(a)users.sourceforge.net


    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, version 3 of the License.


    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, http://www.gnu.org/copyleft/gpl.html



*******************************************************************************
$Rev:: 351                      $: Revision of last commit
$Author:: gmbertani             $: Author of last commit
$Date:: 2020-08-26 00:13:47 +02#$: Date of last commit
$Id: iqdevice.cpp 351 2020-08-26 00:13:47 gmbertani $
*******************************************************************************/

#include "setup.h"
#include "iqdevice.h"



IQdevice::IQdevice(Settings* appSettings, Pool<IQbuf*>* bPool, QThread *parentThread)
{
    //setObjectName("IQdevice thread");
    if(parentThread != nullptr)
    {
        setParent(parentThread);
    }
    //MY_ASSERT( nullptr !=  parentThread);
    //MYINFO << "parentThread=" << parentThread << " parent()=" << parent();

    MY_ASSERT( nullptr !=  appSettings);
    as = appSettings;

    MY_ASSERT( nullptr !=  bPool);
    pb = bPool;

    ready = false;
    resamplerBypass = false;
    myCfgChanged = false;
    sr = as->getSampleRate();
    bw = as->getBandwidth();
    tune = as->getTune();
    lowBound  = tune - bw/2;
    highBound = tune + bw/2;
    deviceName = as->getDevice();
}

IQdevice::~IQdevice()
{

}


QList<uint32_t> IQdevice::getPackedRates()
{
    bool ok = false;
    QList<uint32_t>uRates;
    QString rate;
    foreach(rate, rates)
    {
        uRates.append( rate.toUInt(&ok) );
    }
    return uRates;
}


QList<float> IQdevice::getPackedGains()
{
    bool ok = false;
    QList<float>pGains;
    QString gain;
    float fGain;
    foreach(gain, gains)
    {
        if(gain == "AUTO")
        {
            gain = "255.0";
        }
        fGain = gain.toFloat(&ok);
        pGains.append(fGain);
    }
    return pGains;
}

void IQdevice::setPackedRates(QList<uint32_t> pRates)
{
    rates.clear();
    uint32_t rate;
    QString sRate;
    foreach(rate, pRates)
    {
        sRate.setNum(rate);
        rates.append(sRate);
    }
}

void IQdevice::setPackedGains(QList<float> pGains)
{
    gains.clear();
    float gain;
    QString sGain;
    foreach(gain, pGains)
    {
        if(gain == 255.0)
        {
            sGain = "AUTO";
        }
        else
        {
            sGain.setNum(gain , 'f', 2);
        }
        gains.append(sGain);
    }
}
