/******************************************************************************

    Echoes is a RF spectrograph for RTL-SDR devices designed for meteor scatter
    Copyright (C) 2018  Giuseppe Massimo Bertani gmbertani(a)users.sourceforge.net


    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, version 3 of the License.
    

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, http://www.gnu.org/copyleft/gpl.html






*******************************************************************************
$Rev:: 367                      $: Revision of last commit
$Author:: gmbertani             $: Author of last commit
$Date:: 2018-11-23 18:22:34 +01#$: Date of last commit
$Id: mainwindow.h 367 2018-11-23 17:22:34Z gmbertani $
*******************************************************************************/



#ifndef MAINWINDOW_H
#define MAINWINDOW_H


#include <QMainWindow>
#include <QtCore>
#include <QtWidgets>
#include "settings.h"


namespace Ui {
    class MainWindow;
}

class Control;
class Radio;
class SiteInfos;
class Waterfall;

enum GUItabs
{
    GT_GLOBAL,
    GT_DEVICE,
    GT_FFT,
    GT_OUTPUT,
    GT_REPORT,
    GT_PREFERENCES,
    GT_TOTAL
};


class MainWindow : public QMainWindow
{
    Q_OBJECT

public:


    ///
    /// \brief MainWindow
    /// \param appSettings
    /// \param appControl
    /// \param parent
    ///
    explicit MainWindow(Settings* appSettings, Control* appControl, QWidget *parent = nullptr);
    ~MainWindow();

public slots:
    //status bar
    void slotShowStatus(const QString& status, int appState = AST_NONE );
    void slotStart();
    void slotStop();
    void slotReport();
    void slotAutoReport();
    void showBusy();    //shows hourglass cursor
    void showFree();    //shows arrow cursor
    void slotAcqStopped();
    void slotAcqStarted();


protected slots:

    //command pushbuttons
    void slotOpenConfig();
    void slotSaveAs();
    void slotAboutDialog();
    void slotQuit();
    void slotSiteInfos();
    void slotFindGNUplot();
    void slotFlatten();

    //LCD tune pushbuttons
    void slotTuneAdd10M();
    void slotTuneAdd1M();
    void slotTuneAdd100k();
    void slotTuneAdd10k();
    void slotTuneAdd1k();
    void slotTuneSub10M();
    void slotTuneSub1M();
    void slotTuneSub100k();
    void slotTuneSub10k();
    void slotTuneSub1k();

    //clicking on LCD tune
    void slotEnterTune(const QPoint& pos);

    void slotBWadd1k();
    void slotBWadd1M();
    void slotBWadd100k();
    void slotBWadd10k();
    void slotBWsub1k();
    void slotBWsub1M();
    void slotBWsub100k();
    void slotBWsub10k();

    //clicking on LCD subsampling
    void slotEnterBW(const QPoint& pos);

    //bypassing subsampler
    void slotSetSsBypass( int value );

    //variable elements comboboxes
    bool slotSetDevice( const QString& text );
    void slotSetSampleRate  ( const QString& text );
    void slotSetGain        ( const QString& text );

    //subwindows control checkboxes
    void slotReopen();
    void slotAdjustResolution();
    void slotSetSbThresholdsParam();
    void slotValidateUpThreshold();
    void slotValidateDnThreshold();

    void slotUpdateSysInfo();
    void slotFocusChanged(QWidget* old, QWidget* now);
    void slotSetAcqMode( E_ACQ_MODE am );

    //initial GUI setup
    void slotGUIinit();


signals:
    void stateChanged(int);


private:
    Ui::MainWindow *ui;

protected:
    Settings* as;
    Control*  ac;
    SiteInfos* si;
    Radio* r;
    Waterfall*  wf;
    QTimer*   sysCheck;

    QVector< QList<QWidget*>  >guiWidgetsList;

    int       tune;     //LCD tune value
    int       bw;       //LCD bandwidth value

    int ast;            ///acquisition status

    int busyInst;       ///instance counter for showBusy() calls

    bool init;          ///program just started
    bool outputEnabled; ///acquisition mode set
    bool deviceChanged; ///device has changed manually while initing

    ///
    /// \brief blockAllSignals
    /// \param block
    //prevents I/O controls
    //(comboboxes, spinboxes, checkboxes...)
    //to send signals
    //when modified programmatically
    void blockAllSignals(bool block);


    ///
    /// \brief setTitle
    ///Formats the titlebar
    void setTitle();

    virtual void moveEvent ( QMoveEvent * event );
    virtual void resizeEvent ( QResizeEvent* event );


    ///
    /// \brief eventFilter
    /// \param obj
    /// \param event
    /// \return
    //to disable tooltips globally
    ///
    bool eventFilter(QObject *obj, QEvent *event);

    ///
    /// \brief checkReportCoverage
    //checks and corrects the dates for report coverage
    ///
    void checkReportCoverage();

    ///
    /// \brief GUIrefresh
    ///
    void GUIrefresh();

};

#endif // MAINWINDOW_H
