/******************************************************************************

    Echoes is a RF spectrograph for RTL-SDR devices designed for meteor scatter
    Copyright (C) 2018  Giuseppe Massimo Bertani gmbertani(a)users.sourceforge.net


    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, version 3 of the License.


    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, http://www.gnu.org/copyleft/gpl.html






*******************************************************************************
$Rev:: 381                      $: Revision of last commit
$Author:: gmbertani             $: Author of last commit
$Date:: 2018-12-20 08:42:10 +01#$: Date of last commit
$Id: setup.h 381 2018-12-20 07:42:10Z gmbertani $
*******************************************************************************/


#ifndef SETUP_H
#define SETUP_H

#include <QtCore>

enum LOG_LEVELS
{
    ECHOES_LOG_NONE,               // do not create a program log
    ECHOES_LOG_FATAL,              // only fatal messages (crashes) are logged
    ECHOES_LOG_CRITICAL,           // logs fatal and critical messages (alerts about possible crashes)
    ECHOES_LOG_WARNINGS,           // logs warnings too (the program does not behave as expected)
    ECHOES_LOG_INFO,               // logs info messages too

    ECHOES_LOG_ALL                 // logs everything including debug messages (huge logs)
};


//final application name
#define TARGET_NAME             "echoes"
#define TARGET_DESC             "Echoes is a RF spectrograph for RTL-SDR devices designed for meteor scatter"
#define COMPANY_NAME            "GABB"

#define FULL_CONSOLE_APPNAME    "console_echoes"

#ifdef _DEBUG
#undef APP_VERSION
#undef BUILD_DATE
#endif


#ifndef BUILD_DATE
#define BUILD_DATE "2065/12/08 00:00:00"
#endif

#ifndef APP_VERSION
#define APP_VERSION "00.00"
#endif 

#define BUFFER_DUMP            4096
#define DEFAULT_SCALING        1.0F                 //fft output values scaling = none

#define KILL_TIMEOUT           3                   //seconds before terminating stale threads

//CSV columns separator
#define CSV_SEP                 ';'

//Automatic shots prefix
#define AUTOSHOT_PREFIX        "autoshot_"
//Manual shots prefix
#define MANSHOT_PREFIX         "manshot_"

//CSV statistic data file prefix
#define CSV_PREFIX              "scan_"

//GNUplot files prefix
#define SPEC3D_PREFIX           "spec3D_"
#define SPECMAP_PREFIX          "spectra_"
#define POW2D_PREFIX            "power_"

//daily report table
#define DAILY_PREFIX            "daily_"

//input file for neural network (AI feeds)
#define AI_FEED_PREFIX           "feed_"

//configuration files extension
#define CONFIG_EXT              ".rts"
//table files extension
#define TABLE_EXT               ".csv"
//gnuplot data files extension
#define GP_DATA_EXT              ".dat"
//gnuplot command files extension
#define GP_CMD_EXT               ".plt"
//screenshot images extensions
#define SSHOT_EXT               ".png"

//FFTW3 wisdom file extension
#define FFTW_WISDOM_EXT         ".wdm"

//HTML report extension
#define HTML_EXT                ".html"

//PDF report extension
#define PDF_EXT                 ".pdf"

//daily counters file name+ext
#define DAILYCTR_NAME            "daily_counters.ds"

//echoes internals statistic plot
#define INNER_STATISTIC_PLOT    TARGET_NAME+QString("-")+as->getConfigName()+TABLE_EXT //GP_DATA_EXT

//temporary gnuplot command file for reports
#define TEMP_GP_CMD             "temp.plt"

//CSS style sheet to customize report
#define REPORT_CSS              "fullreport.css"

//gnuplot executable path (Linux)
#define DEFAULT_GNUPLOT_PATH    "/usr/bin/gnuplot"

//maximum noise alloweed for automatic capturing (0=unlimited)
#define DEFAULT_NOISE_LIMIT     0

//dongle server port
#define DEFAULT_SERVER_PORT     12345

//dongle server address
#define DEFAULT_SERVER_ADDRESS  "0.0.0.0"

//max.UDP datagram size
#define MAX_DGRAM_SIZE 512

//min time resolution in mS
#define TIME_BASE               1

//disk space checking cadence mS
#define SYS_CHECK_INTERVAL      30000

//minimum storage for circular buffers
#define CIRCBUF_MIN             10

//array pool size:
#define DEFAULT_POOLS_SIZE      14

//maximum input buffer size
#define MAX_SAMPLE_BUF_SIZE     (MAX_SAMPLE_RATE_HZ)

//maximum number of FFT bins = 2^20
#define MAX_FFT_BINS            1048576

//speed of light [m/s]
#define SPEED_OF_LIGHT          299792458

//max tune frequency
#define MAX_TUNE_HZ             2000000000       //hz (2 GHz)

//minimum tune frequency
#define MIN_TUNE_HZ             10000000        //hz (10 MHz)

//maximum sample rate allowed by RTL-SDR dongles
#define MAX_SAMPLE_RATE_HZ      3200000

//step increment for frequency rulers
#define HORZ_MIN_TICKS_STEP     100            //hz

//dBfs values scale start at
#define MIN_DBFS             (-80.0)

//dBfs values scale ends at
#define MAX_DBFS             40.0

//invalid dBfs value
#define INVALID_DBFS        -1000.0

//dBfs color scale delta between values [dBfs]
#define DEFAULT_DBFS_STEP    15

//Minimum power axle ticks for power graphs
//#define MIN_POWER_TICKS     6

//Waterfall widget frequency axle ticks
#define WF_FREQ_TICKS       15
//Waterfall widget time axle ticks
#define WF_TIME_TICKS       20

//fixed rulers: max nr. of ticks between lines at each side of the origin (widget center) ALWAYS ODD
//#define MAX_FIXED_RULER_TICKS       15               //5 left + origin + 5 right = 11

//scrolling rulers: min nr. of ticks between lines
#define MIN_SCROLLING_RULER_TICKS   10

#define FREQ_SCALE_ROUND_BY     1000             //steps of BW and minimum bandwidth
#define LOWEST_RESOLUTION       1000             //hz - to be set in spinbox too as maximum value. Minumum must be 1
#define RESOLUTION_STEP         0.1             //hz - minimum increment/decrement step

//postprocessing scan cadence [min]
#define PP_CADENCE              3

//maximum days covered by a report document
#define MAXIMUM_REPORT_COVERAGE 31

//delay in loops since acquisition start before measuring the scan time
#define MEASURE_DELAY_LOOP      500

//midnight magic
#define MIDNIGHT_SWAP           0x1234

//magic number for daily counters data file
#define DAILYCTR_MAGIC          0xaa55a55a

//sync word for IQbuf UDP transfers
#define SYNC_IQBUF              0x2015

//sync word for server configuration UDP transfers
#define SYNC_SRVCONF 0x6a21

//hardcoded default settings:

#define DEFAULT_CONFIG_NAME    "default"        //default configuration file
#define DEFAULT_MAINWND_GEOM   QRect(100,100,340,750)

//device settings
#define DEFAULT_DEVICE          "0:UNKNOWN"
#define DEFAULT_RATE            MAX_SAMPLE_RATE_HZ  //hz
#define DEFAULT_TUNE            144000000        //hz
#define DEFAULT_GAIN            496           //49.60 maximum for R820T dongles
#define DEFAULT_PPMERR          0             //ppm/100


//FFT settings:
#define DEFAULT_WINDOW              0               //FTW_RECTANGLE
#define DEFAULT_FFT_BINS            4096            // default FFT points
#define DEFAULT_RESOLUTION          Q_INT64_C(78125000000)  // [hz / 10e8]
#define DEFAULT_SSBYPASS            0
#define DEFAULT_BW                  DEFAULT_RATE    //hz

//output settings:
#define DEFAULT_ACQ_MODE            1               //continuous
#define DEFAULT_INTVL               100             //ms
#define DEFAULT_MAX_SHOTS           0               //0=continuous mode
#define DEFAULT_RECTIME             0               //sec
#define DEFAULT_AUTO_AFTER          0               //sec
#define DEFAULT_THRESHOLDS          0               //diffential thresholds (default for Echoes <= 0.25)
#define DEFAULT_AUTO_UP_THRESHOLD   0               //power peaks detection threshold S-N [dBfs/100]
#define DEFAULT_AUTO_DN_THRESHOLD   0               //below this threshold, the peak is considered terminated [dBfs/100]
#define DEFAULT_AUTO_TRANGE         20              //power peaks detection frequency range [%]
#define DEFAULT_GNUPLOT             Qt::Unchecked   //do not produce GNUplot files
#define DEFAULT_SCREENSHOTS         Qt::Checked     //always produce screenshots
#define DEFAULT_AI_FEEDS            Qt::Unchecked   //AI input files generation must be enabled explicitly
#define DEFAULT_ERASE_LOGS          Qt::Unchecked   //erase
#define DEFAULT_ERASE_SHOTS         Qt::Unchecked   //erase
#define DEFAULT_PLOT_TYPE           0               //default plot type : 3d-->2d color mapped
#define DEFAULT_DATA_LASTING        40              //delete data files oldest than days
#define DEFAULT_N_SCANS             10              //number of averaged scans to calculate N
#define DEFAULT_JOIN_TIME           1000            //minimum time between consecutive events in ms
#define DEFAULT_FREE_SPACE          0               //minimum space to keep free on working drive in GB, 0=no limits
#define DEFAULT_GNUPLOT_PALETTE     "-150 \"#000000\", -114 \"#0000ff\", -98 \"#800080\", -82 \"#ffa500\", -66 \"#ffff00\", -50 \"#ffffff\", 50 \"#ffffff\""

//preferences
#define DEFAULT_WSEC_TICKS          Qt::Checked      //shown
#define DEFAULT_HZ_TICKS            Qt::Checked      //shown
#define DEFAULT_DBFS_TICKS          Qt::Checked      //shown
#define DEFAULT_TOOLTIPS            Qt::Unchecked      //tooltips showed
#define DEFAULT_PING                Qt::Checked      //ping sound enabled
#define DEFAULT_WF_PALETTE          0                //waterfall palette: 0=b/w, 1=color

//report settings
#define DEFAULT_UNDERDENSE_MS       1000
#define DEFAULT_OVERDENSE_SEC       50
#define DEFAULT_COLORGRAPH          Qt::Checked
#define DEFAULT_SITEINFOS           Qt::Checked
#define DEFAULT_OVERDENSE_SHOTS     Qt::Unchecked
#define DEFAULT_UNDERDENSE_SHOTS    Qt::Unchecked
#define DEFAULT_OVERDENSE_PLOTS     Qt::Unchecked
#define DEFAULT_UNDERDENSE_PLOTS    Qt::Unchecked
#define DEFAULT_SHOTS_DETAILS       Qt::Unchecked
#define DEFAULT_SUMMARY             Qt::Checked
#define DEFAULT_RESTART             Qt::Unchecked
#define DEFAULT_AUTO_REPORT         Qt::Unchecked
#define DEFAULT_CARRIER_FILTER      Qt::Checked
#define DEFAULT_LIGHTINGS_FILTER    Qt::Checked
#define DEFAULT_SATURATION_FILTER   Qt::Checked

//waterfall settings:
#define DEFAULT_WATERFALL_GEOM QRect(300,300,1024,768)
#define DEFAULT_OFFSET         0                    //hz
#define DEFAULT_ZOOM           10                   // [X / 10]
#define DEFAULT_DBFS_ZOOM      50                   //percentage
#define DEFAULT_BRIGHTNESS     60                   //absolute dBfs
#define DEFAULT_CONTRAST       90                   //absolute dBfs
#define DEFAULT_POWEROFFSET    0
#define DEFAULT_POWERZOOM      1
#define DEFAULT_NOTCH_WIDTH    10                   //Hz
#define MAX_NOTCH_WIDTH        99999                //Hz
#define MANSHOT_DEBOUNCE_TICKS      50
#define PG_ALIGNMENT_EVERY_SCANS    300

//site infos - some fake data
#define DEFAULT_LOGO           ":/logo"
#define DEFAULT_LATITUDE       +45.516667
#define DEFAULT_LONGITUDE      -9.583333
#define DEFAULT_ALTITUDE       125
#define DEFAULT_STATION_NAME   QString("GABB")
#define DEFAULT_CONTACT        QString("gmbertani@users.sourceforge.net")
#define DEFAULT_RXSETUP        QString("-")
#define DEFAULT_NOTES          QString("-")


#define AUTO_GAIN               -10           //negative values means automatic gain
#define GLOBAL_STYLESHEET_FILE  ":/qss"
#define WORKING_PATH           TARGET_NAME     //subdir under $HOME
#define NOTIFY_SOUND           ":/ping"
#define APP_LANG               "en"
#define IMAGE_FORMAT            QImage::Format_RGB32
#define MAX_SYS_ERRORS          10

#ifdef NIX
    #define GNUPLOT_TERM        "X11"
    #define LOGFILE             "/dev/log"          //journal / syslog
#else
    #define GNUPLOT_TERM        "wxt"
#define LOGFILE             TARGET_NAME".log"   //application log file
#define LOGFILE_BAK         LOGFILE".bak"       //previous session log file
#endif

#define MY_ASSERT(condition) \
    if( (condition) == false ) { MYCRITICAL << "MY_ASSERT failed"; }

//comment to avoid the waterfall to redraw the latest scan in case of missing input data
#define SCAN_REPEATING  1

//comment to integrate the input scans by average instead of peaks
//#define INTEGRATION_BY_PEAKS 1




#endif // SETUP_H
