/******************************************************************************

    Echoes is a RF spectrograph for RTL-SDR devices designed for meteor scatter
    Copyright (C) 2018  Giuseppe Massimo Bertani gmbertani(a)users.sourceforge.net


    This program is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, version 3 of the License.
    

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program.  If not, http://www.gnu.org/copyleft/gpl.html






*******************************************************************************
$Rev:: 40                       $: Revision of last commit
$Author:: gmbertani             $: Author of last commit
$Date:: 2018-01-29 10:24:57 +01#$: Date of last commit
$Id: siteinfos.cpp 40 2018-01-29 09:24:57Z gmbertani $
*******************************************************************************/
#include "ui_siteinfos.h"
#include "mainwindow.h"
#include "siteinfos.h"


SiteInfos::SiteInfos(Settings* appSettings, QWidget *parent) :
    QWidget(parent),
    ui(new Ui::SiteInfos)
{
    setObjectName("SiteInfos widget");
    ui->setupUi(this);

    MY_ASSERT( nullptr !=  appSettings);
    as = appSettings;

    posValid = false;

    /*
     *
    pis = QGeoPositionInfoSource::createDefaultSource(this);
    if(pis != 0)
    {
        if(pis->error() == QGeoPositionInfoSource::NoError)
        {
            QGeoPositionInfo pi = pis->lastKnownPosition();
            QGeoCoordinate coords = pi.coordinate();
            if( qIsNaN( coords.latitude() ) == false && qIsNaN( coords.longitude() ) == false )
            {
                pis->requestUpdate();
                posValid = true;
                MYINFO << "valid position info source found.";
            }
        }
    }
    */

    connect(ui->pbLogo,     SIGNAL( pressed() ), this, SLOT( slotChangeLogo() ) );
    connect(ui->pbOk,       SIGNAL( pressed() ), this, SLOT( slotAccept() ) );
    connect(ui->pbCancel,   SIGNAL( pressed() ), this, SLOT( slotReload() ) );

}

SiteInfos::~SiteInfos()
{
    delete ui;
}

void SiteInfos::slotChangeLogo()
{

#ifdef NO_NATIVE_DIALOGS
    logoFile = QFileDialog::getOpenFileName(
        this,
        tr("Open logo image"),
        "*", // RESOURCE_PATH,
        "logo images (*.png *.jpeg *.jpg)",
        0,
        QFileDialog::DontUseNativeDialog);

//lug11,2016 - WORKAROUND for native dialog crashes under OpenSuse 13.1 / Qt4 / KDE / 32bit
//may25,2017 - WORKAROUND for Native dialogs buggy under linux
#else

    logoFile = QFileDialog::getOpenFileName(
        this,
        tr("Open logo image"),
        "*", // RESOURCE_PATH,
        tr("logo images (*.png *.jpeg *.jpg)"),
        0);
#endif

    if( logoFile.isEmpty() )
    {
       //no file specified
        return;
    }

    QPixmap logo(logoFile);
    QIcon logoIcon(logo);
    ui->pbLogo->setText("");
    ui->pbLogo->setIcon( logoIcon );
    ui->pbLogo->setIconSize( ui->pbLogo->size() );

}



void SiteInfos::slotUpdatePosition()
{
    /*
    if(posValid == true)
    {
        //retrieves the position from the system, if available

        QGeoPositionInfo pi = pis->lastKnownPosition();
        QGeoCoordinate coords = pi.coordinate();

        QString s = QString("%1").arg( coords.latitude() );
        ui->leLatitude->setText(s);

        s = QString("%1").arg( coords.longitude() );
        ui->leLongitude->setText(s);

        s = QString("%1").arg( coords.altitude() );
        ui->leAltitude->setText(s);
    }
    */
}


void SiteInfos::slotAccept()
{
    bool ok = false;
    QString s;
    double value;

    //pressing OK all the changed settings are stored in config file

    s = ui->leLatitude->text();
    value = s.toDouble(&ok);
    if(ok == true)
    {
        as->setLat(value);
    }

    s = ui->leLongitude->text();
    value = s.toDouble(&ok);
    if(ok == true)
    {
        as->setLong(value);
    }

    s = ui->leAltitude->text();
    value = s.toDouble(&ok);
    if(ok == true)
    {
        as->setAlt(value);
    }

    as->setStationName( ui->leStation->text() );
    as->setRxSetup( ui->pteSetup->toPlainText() );
    as->setContact( ui->pteContact->toPlainText() );
    as->setNotes( ui->pteNotes->toPlainText() );

    as->setLogo( logoFile );
    emit logoChanged();

    close();
}


void SiteInfos::slotReload()
{
    //pressing Cancel all the settings are reloaded from config file

    QString s;
    s.setNum( as->getLat() );
    ui->leLatitude->setText(s);

    s.setNum( as->getLong() );
    ui->leLongitude->setText(s);

    s.setNum( as->getAlt() );
    ui->leAltitude->setText(s);

    ui->leStation->setText( as->getStationName() );

    ui->pteContact->setPlainText( as->getContact() );
    ui->pteSetup->setPlainText( as->getRxSetup() );
    ui->pteNotes->setPlainText( as->getNotes() );

    logoFile = as->getLogo();
    QPixmap logo( logoFile );
    QIcon logoIcon(logo);
    ui->pbLogo->setText("");
    ui->pbLogo->setIcon( logoIcon );
    ui->pbLogo->setIconSize( ui->pbLogo->size() );
    close();
}


void SiteInfos::GUIinit()
{
    slotReload();
}

